@@ -45,6 +45,7 @@ import sys
 
 from bandit.core import constants
 from bandit.core import test_properties
+from bandit.formatters import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -149,13 +150,15 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
     bits.append('\tTotal lines skipped (#nosec): %i' %
                 (manager.metrics.data['_totals']['nosec']))
 
+    skipped = manager.get_skipped()
     bits.append(get_metrics(manager))
-    bits.append("Files skipped (%i):" % len(manager.skipped))
-    bits.extend(["\t%s (%s)" % skip for skip in manager.skipped])
+    bits.append("Files skipped (%i):" % len(skipped))
+    bits.extend(["\t%s (%s)" % skip for skip in skipped])
     result = '\n'.join([bit for bit in bits]) + '\n'
 
     with fileobj:
-        fileobj.write(str(result.encode('utf-8')))
+        wrapped_file = utils.wrap_file_object(fileobj)
+        wrapped_file.write(utils.convert_file_contents(result))
 
     if fileobj.name != sys.stdout.name:
         LOG.info("Text output written to file: %s", fileobj.name)
