@@ -20,28 +20,16 @@ import re
 import bandit
 from bandit.core import test_properties as test
 
-
-def _has_special_characters(command):
-    # check if it contains any of the characters that may cause globing,
-    # multiple commands, subshell, or variable resolution
-    # glob: [ { * ?
-    # variable: $
-    # subshell: ` $
-    return bool(re.search(r'[{|\[;$\*\?`]', command))
+# yuck, regex: starts with a windows drive letter (eg C:)
+# or one of our path delimeter characters (/, \, .)
+full_path_match = re.compile(r'^(?:[A-Za-z](?=\:)|[\\\/\.])')
 
 
 def _evaluate_shell_call(context):
     no_formatting = isinstance(context.node.args[0], ast.Str)
-    if no_formatting:
-        command = context.call_args[0]
-        no_special_chars = not _has_special_characters(command)
-    else:
-        no_special_chars = False
 
-    if no_formatting and no_special_chars:
+    if no_formatting:
         return bandit.LOW
-    elif no_formatting:
-        return bandit.MEDIUM
     else:
         return bandit.HIGH
 
@@ -204,15 +192,6 @@ def subprocess_popen_with_shell_equals_true(context, config):
                              'rewriting without shell',
                         lineno=context.get_lineno_for_call_arg('shell'),
                     )
-                elif sev == bandit.MEDIUM:
-                    return bandit.Issue(
-                        severity=bandit.MEDIUM,
-                        confidence=bandit.HIGH,
-                        text='call with shell=True contains special shell '
-                             'characters, consider moving extra logic into '
-                             'Python code',
-                        lineno=context.get_lineno_for_call_arg('shell'),
-                    )
                 else:
                     return bandit.Issue(
                         severity=bandit.HIGH,
@@ -464,14 +443,6 @@ def start_process_with_a_shell(context, config):
                          'Seems safe, but may be changed in the future, '
                          'consider rewriting without shell'
                 )
-            elif sev == bandit.MEDIUM:
-                return bandit.Issue(
-                    severity=bandit.MEDIUM,
-                    confidence=bandit.HIGH,
-                    text='Starting a process with a shell and special shell '
-                         'characters, consider moving extra logic into '
-                         'Python code'
-                )
             else:
                 return bandit.Issue(
                     severity=bandit.HIGH,
@@ -649,14 +620,13 @@ def start_process_with_partial_path(context, config):
            context.call_function_name_qual in config['shell'] or
            context.call_function_name_qual in config['no_shell']):
 
-            delims = ['/', '\\', '.']
             node = context.node.args[0]
             # some calls take an arg list, check the first part
             if isinstance(node, ast.List):
                 node = node.elts[0]
 
             # make sure the param is a string literal and not a var name
-            if isinstance(node, ast.Str) and node.s[0] not in delims:
+            if isinstance(node, ast.Str) and not full_path_match.match(node.s):
                 return bandit.Issue(
                     severity=bandit.LOW,
                     confidence=bandit.HIGH,
