@@ -15,17 +15,30 @@
 # under the License.
 
 import bandit
-from bandit.core.test_properties import *
+from bandit.core import test_properties as test
 
 
 def get_bad_proto_versions(config):
     return config['bad_protocol_versions']
 
 
-@takes_config
-@checks('Call')
+def gen_config(name):
+    if name == 'ssl_with_bad_version':
+        return {'bad_protocol_versions':
+                ['PROTOCOL_SSLv2',
+                 'SSLv2_METHOD',
+                 'SSLv23_METHOD',
+                 'PROTOCOL_SSLv3',  # strict option
+                 'PROTOCOL_TLSv1',  # strict option
+                 'SSLv3_METHOD',    # strict option
+                 'TLSv1_METHOD']}   # strict option
+
+
+@test.takes_config
+@test.checks('Call')
+@test.test_id('B502')
 def ssl_with_bad_version(context, config):
-    """Test for SSL use with bad version used
+    """**B502: Test for SSL use with bad version used**
 
     Several highly publicized exploitable flaws have been discovered
     in all versions of SSL and early versions of TLS. It is strongly
@@ -66,7 +79,7 @@ def ssl_with_bad_version(context, config):
     ``OP_NO_SSLv3`` flags for this purpose.
 
 
-    Config Options:
+    **Config Options:**
 
     .. code-block:: yaml
 
@@ -81,7 +94,7 @@ def ssl_with_bad_version(context, config):
                 - TLSv1_METHOD    # strict option
 
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -93,49 +106,55 @@ def ssl_with_bad_version(context, config):
         13  ssl.wrap_socket(ssl_version=ssl.PROTOCOL_SSLv3)
         14  ssl.wrap_socket(ssl_version=ssl.PROTOCOL_TLSv1)
 
-    References:
+    .. seealso::
 
-    - http://heartbleed.com/
-    - https://poodlebleed.com/
-    - https://security.openstack.org/
-    - https://security.openstack.org/guidelines/dg_move-data-securely.html
+     - http://heartbleed.com/
+     - https://poodlebleed.com/
+     - https://security.openstack.org/
+     - https://security.openstack.org/guidelines/dg_move-data-securely.html
 
     .. versionadded:: 0.9.0
     """
     bad_ssl_versions = get_bad_proto_versions(config)
-    if (context.call_function_name_qual == 'ssl.wrap_socket'):
+    if context.call_function_name_qual == 'ssl.wrap_socket':
         if context.check_call_arg_value('ssl_version', bad_ssl_versions):
             return bandit.Issue(
                 severity=bandit.HIGH,
                 confidence=bandit.HIGH,
                 text="ssl.wrap_socket call with insecure SSL/TLS protocol "
-                     "version identified, security issue."
+                     "version identified, security issue.",
+                lineno=context.get_lineno_for_call_arg('ssl_version'),
             )
-    elif (context.call_function_name_qual == 'pyOpenSSL.SSL.Context'):
+    elif context.call_function_name_qual == 'pyOpenSSL.SSL.Context':
         if context.check_call_arg_value('method', bad_ssl_versions):
             return bandit.Issue(
                 severity=bandit.HIGH,
                 confidence=bandit.HIGH,
                 text="SSL.Context call with insecure SSL/TLS protocol "
-                     "version identified, security issue."
+                     "version identified, security issue.",
+                lineno=context.get_lineno_for_call_arg('method'),
             )
 
     elif (context.call_function_name_qual != 'ssl.wrap_socket' and
           context.call_function_name_qual != 'pyOpenSSL.SSL.Context'):
         if (context.check_call_arg_value('method', bad_ssl_versions) or
-           context.check_call_arg_value('ssl_version', bad_ssl_versions)):
+                context.check_call_arg_value('ssl_version', bad_ssl_versions)):
+            lineno = (context.get_lineno_for_call_arg('method') or
+                      context.get_lineno_for_call_arg('ssl_version'))
             return bandit.Issue(
                 severity=bandit.MEDIUM,
                 confidence=bandit.MEDIUM,
                 text="Function call with insecure SSL/TLS protocol "
-                     "identified, possible security issue."
+                     "identified, possible security issue.",
+                lineno=lineno,
             )
 
 
-@takes_config("ssl_with_bad_version")
-@checks('FunctionDef')
+@test.takes_config("ssl_with_bad_version")
+@test.checks('FunctionDef')
+@test.test_id('B503')
 def ssl_with_bad_defaults(context, config):
-    """Test for SSL use with bad defaults specified
+    """**B503: Test for SSL use with bad defaults specified**
 
     This plugin is part of a family of tests that detect the use of known bad
     versions of SSL/TLS, please see :doc:`../plugins/ssl_with_bad_version` for
@@ -151,14 +170,13 @@ def ssl_with_bad_defaults(context, config):
     - :doc:`../plugins/ssl_with_bad_version`
     - :doc:`../plugins/ssl_with_no_version`
 
-
-    Config Options:
+    **Config Options:**
 
     This test shares the configuration provided for the standard
     :doc:`../plugins/ssl_with_bad_version` test, please refer to its
     documentation.
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -170,12 +188,12 @@ def ssl_with_bad_defaults(context, config):
         28  def open_ssl_socket(version=SSL.SSLv2_METHOD):
         29      pass
 
-    References:
+    .. seealso::
 
-    - http://heartbleed.com/
-    - https://poodlebleed.com/
-    - https://security.openstack.org/
-    - https://security.openstack.org/guidelines/dg_move-data-securely.html
+     - http://heartbleed.com/
+     - https://poodlebleed.com/
+     - https://security.openstack.org/
+     - https://security.openstack.org/guidelines/dg_move-data-securely.html
 
     .. versionadded:: 0.9.0
     """
@@ -193,9 +211,10 @@ def ssl_with_bad_defaults(context, config):
             )
 
 
-@checks('Call')
+@test.checks('Call')
+@test.test_id('B504')
 def ssl_with_no_version(context):
-    """Test for SSL use with no version specified
+    """**B504: Test for SSL use with no version specified**
 
     This plugin is part of a family of tests that detect the use of known bad
     versions of SSL/TLS, please see :doc:`../plugins/ssl_with_bad_version` for
@@ -211,14 +230,13 @@ def ssl_with_no_version(context):
     - :doc:`../plugins/ssl_with_bad_version`
     - :doc:`../plugins/ssl_with_bad_defaults`
 
-
-    Config Options:
+    **Config Options:**
 
     This test shares the configuration provided for the standard
     :doc:`../plugins/ssl_with_bad_version` test, please refer to its
     documentation.
 
-    Sample Output:
+    :Example:
 
     .. code-block:: none
 
@@ -231,16 +249,16 @@ def ssl_with_no_version(context):
         23  ssl.wrap_socket()
         24
 
-    References:
+    .. seealso::
 
-    - http://heartbleed.com/
-    - https://poodlebleed.com/
-    - https://security.openstack.org/
-    - https://security.openstack.org/guidelines/dg_move-data-securely.html
+     - http://heartbleed.com/
+     - https://poodlebleed.com/
+     - https://security.openstack.org/
+     - https://security.openstack.org/guidelines/dg_move-data-securely.html
 
     .. versionadded:: 0.9.0
     """
-    if (context.call_function_name_qual == 'ssl.wrap_socket'):
+    if context.call_function_name_qual == 'ssl.wrap_socket':
         if context.check_call_arg_value('ssl_version') is None:
             # check_call_arg_value() returns False if the argument is found
             # but does not match the supplied value (or the default None).
@@ -251,5 +269,6 @@ def ssl_with_no_version(context):
                 confidence=bandit.MEDIUM,
                 text="ssl.wrap_socket call with no SSL/TLS protocol version "
                      "specified, the default SSLv23 could be insecure, "
-                     "possible security issue."
+                     "possible security issue.",
+                lineno=context.get_lineno_for_call_arg('ssl_version'),
             )
