@@ -16,3 +16,7 @@ def NoMatch2(password):
 doLogin(password="blerg")
 password = "blerg"
 d["password"] = "blerg"
+
+
+def NoMatch3((a, b)):
+    pass
