@@ -133,6 +133,11 @@ class FunctionalTests(testtools.TestCase):
         expect = {'SEVERITY': {'MEDIUM': 3}, 'CONFIDENCE': {'HIGH': 3}}
         self.check_example('eval.py', expect)
 
+    def test_mark_safe(self):
+        '''Test the `mark_safe` example.'''
+        expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'HIGH': 1}}
+        self.check_example('mark_safe.py', expect)
+
     def test_exec(self):
         '''Test the `exec` example.'''
         filename = 'exec-{}.py'
@@ -187,6 +192,11 @@ class FunctionalTests(testtools.TestCase):
         expect = {'SEVERITY': {'HIGH': 2}, 'CONFIDENCE': {'HIGH': 2}}
         self.check_example('telnetlib.py', expect)
 
+    def test_ftp_usage(self):
+        '''Test for `import ftplib` and FTP.* calls.'''
+        expect = {'SEVERITY': {'HIGH': 2}, 'CONFIDENCE': {'HIGH': 2}}
+        self.check_example('ftplib.py', expect)
+
     def test_imports(self):
         '''Test for dangerous imports.'''
         expect = {'SEVERITY': {'LOW': 2}, 'CONFIDENCE': {'HIGH': 2}}
@@ -227,7 +237,7 @@ class FunctionalTests(testtools.TestCase):
 
     def test_os_popen(self):
         '''Test for `os.popen`.'''
-        expect = {'SEVERITY': {'LOW': 7, 'MEDIUM': 1, 'HIGH': 1},
+        expect = {'SEVERITY': {'LOW': 8, 'MEDIUM': 0, 'HIGH': 1},
                   'CONFIDENCE': {'HIGH': 9}}
         self.check_example('os-popen.py', expect)
 
@@ -256,7 +266,7 @@ class FunctionalTests(testtools.TestCase):
 
     def test_popen_wrappers(self):
         '''Test the `popen2` and `commands` modules.'''
-        expect = {'SEVERITY': {'MEDIUM': 7}, 'CONFIDENCE': {'HIGH': 7}}
+        expect = {'SEVERITY': {'LOW': 7}, 'CONFIDENCE': {'HIGH': 7}}
         self.check_example('popen_wrappers.py', expect)
 
     def test_random_module(self):
@@ -297,8 +307,8 @@ class FunctionalTests(testtools.TestCase):
     def test_subprocess_shell(self):
         '''Test for `subprocess.Popen` with `shell=True`.'''
         expect = {
-            'SEVERITY': {'HIGH': 3, 'MEDIUM': 2, 'LOW': 12},
-            'CONFIDENCE': {'HIGH': 16, 'LOW': 1}
+            'SEVERITY': {'HIGH': 3, 'MEDIUM': 1, 'LOW': 14},
+            'CONFIDENCE': {'HIGH': 17, 'LOW': 1}
         }
         self.check_example('subprocess_shell.py', expect)
 
@@ -318,7 +328,7 @@ class FunctionalTests(testtools.TestCase):
     def test_wildcard_injection(self):
         '''Test for wildcard injection in shell commands.'''
         expect = {
-            'SEVERITY': {'HIGH': 4, 'MEDIUM': 4, 'LOW': 6},
+            'SEVERITY': {'HIGH': 4, 'MEDIUM': 0, 'LOW': 10},
             'CONFIDENCE': {'MEDIUM': 5, 'HIGH': 9}
         }
         self.check_example('wildcard-injection.py', expect)
@@ -409,8 +419,8 @@ class FunctionalTests(testtools.TestCase):
 
     def test_partial_path(self):
         '''Test process spawning with partial file paths.'''
-        expect = {'SEVERITY': {'LOW': 9},
-                  'CONFIDENCE': {'HIGH': 9}}
+        expect = {'SEVERITY': {'LOW': 11},
+                  'CONFIDENCE': {'HIGH': 11}}
 
         self.check_example('partial_path_process.py', expect)
 
@@ -455,8 +465,8 @@ class FunctionalTests(testtools.TestCase):
     def test_weak_cryptographic_key(self):
         '''Test for weak key sizes.'''
         expect = {
-            'SEVERITY': {'MEDIUM': 5, 'HIGH': 4},
-            'CONFIDENCE': {'HIGH': 9}
+            'SEVERITY': {'MEDIUM': 6, 'HIGH': 4},
+            'CONFIDENCE': {'HIGH': 10}
         }
         self.check_example('weak_cryptographic_key_sizes.py', expect)
 
