@@ -93,7 +93,4 @@ class JsonFormatterTests(testtools.TestCase):
             self.assertEqual(self.context['linerange'],
                              data['results'][0]['line_range'])
             self.assertEqual(self.check_name, data['results'][0]['test_name'])
-            self.assertEqual('binding.py', data['stats'][0]['filename'])
-            self.assertEqual({'CONFIDENCE': 0, 'SEVERITY': 0},
-                             data['stats'][0]['score'])
             self.assertIn('candidates', data['results'][0])
