@@ -13,7 +13,7 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-from collections import OrderedDict
+import collections
 import tempfile
 
 import mock
@@ -73,9 +73,9 @@ class TextFormatterTests(testtools.TestCase):
         (tmp_fd, self.tmp_fname) = tempfile.mkstemp()
         self.manager.out_file = self.tmp_fname
 
-        get_issue_list.return_value = OrderedDict()
-        b_text.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
-                      lines=5)
+        get_issue_list.return_value = collections.OrderedDict()
+        tmp_file = open(self.tmp_fname, 'w')
+        b_text.report(self.manager, tmp_file, bandit.LOW, bandit.LOW, lines=5)
 
         with open(self.tmp_fname) as f:
             data = f.read()
@@ -114,7 +114,8 @@ class TextFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            b_text.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            b_text.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
@@ -124,7 +125,8 @@ class TextFormatterTests(testtools.TestCase):
 
         # Validate that we're outputting all of the expected fields and the
         # correct values
-        b_text.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+        tmp_file = open(self.tmp_fname, 'w')
+        b_text.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                       lines=5)
         with open(self.tmp_fname) as f:
             data = f.read()
@@ -168,9 +170,8 @@ class TextFormatterTests(testtools.TestCase):
         issue_z = _get_issue_instance()
         issue_z.fname = 'z'
 
-        get_issue_list.return_value = OrderedDict([(issue_a, [issue_x]),
-                                                   (issue_b, [issue_y,
-                                                    issue_z])])
+        get_issue_list.return_value = collections.OrderedDict(
+            [(issue_a, [issue_x]), (issue_b, [issue_y, issue_z])])
 
         # Validate that we're outputting the correct issues
         indent_val = ' ' * 10
@@ -178,7 +179,8 @@ class TextFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            b_text.report(self.manager, self.tmp_fname, bandit.LOW, bandit.LOW,
+            tmp_file = open(self.tmp_fname, 'w')
+            b_text.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
                           lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
